==> haskell-managed-1.0.6-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.6
id: managed-1.0.6-Gbt3igiK5MQ1kU7dtfBy79
key: managed-1.0.6-Gbt3igiK5MQ1kU7dtfBy79
license: BSD3
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
abi: 7faa129d46260d2dcc3c6eb7dc3e7e4e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/managed-1.0.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/managed-1.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/managed-1.0.6
hs-libraries: HSmanaged-1.0.6-Gbt3igiK5MQ1kU7dtfBy79
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-managed-1.0.6-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.6
id: managed-1.0.6-KscD4c3BFNIBs32klcB9iz
key: managed-1.0.6-KscD4c3BFNIBs32klcB9iz
license: BSD-3-Clause
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
abi: d9effffeca43c3cf9494c2fa936523c8
exposed: True
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/managed-1.0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/managed-1.0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/managed-1.0.6
hs-libraries: HSmanaged-1.0.6-KscD4c3BFNIBs32klcB9iz
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
